@@ -25,7 +25,13 @@ class Filesystem(DataStorage):
         delimiter = self.args["delimiter"] if "delimiter" in self.args else ","
         output_file_format = self.args["outputFileFormat"] if "outputFileFormat" in self.args else "csv"
 
-        df.write.options(delimiter=delimiter).\
-            mode('overwrite').\
-            option("header", True).\
-            save(output_dataset, format=output_file_format)
+        if "save_dataset_with_pandas" in self.args:
+
+            df.toPandas().to_csv(output_dataset, delimiter=delimiter, index=False)
+
+        else:
+
+            df.write.options(delimiter=delimiter).\
+                mode('overwrite').\
+                option("header", True).\
+                save(output_dataset, format=output_file_format)
